@@ -21,6 +21,7 @@
  *
  ********************************************************************************/
 
+#include "rhelp.h"
 
 extern "C"
 {
@@ -30,7 +31,6 @@ extern "C"
 #include "rand_pdf.h"
 #include "all_draws.h"
 #include "gen_covar.h"
-#include "rhelp.h"
 }
 #include "corr.h"
 #include "params.h"
@@ -38,7 +38,6 @@ extern "C"
 #include "exp_sep.h"
 #include <math.h>
 #include <stdlib.h>
-#include <stdio.h>
 #include <assert.h>
 #include <string.h>
 #include <string>
@@ -646,7 +645,7 @@ char* ExpSep::State(unsigned int which)
      to get printed also */
 #ifdef PRINTNUG
   string s = "(d";
-  sprintf(buffer, "%d=[", which);
+  snprintf(buffer, BUFFMAX, "%d=[", which);
   s.append(buffer);
 #else
   string s = "";
@@ -656,26 +655,26 @@ char* ExpSep::State(unsigned int which)
 
   /* if linear, then just put a zero and be done;
      otherwise, print the col d-values */ 
-  if(linear) sprintf(buffer, "0]");
+  if(linear) snprintf(buffer, BUFFMAX, "0]");
   else {
     for(unsigned int i=0; i<dim-1; i++) {
 
       /* if this dimension is under the LLM, then show 
        d_eff (which should be zero) / d */
-      if(b[i] == 0.0) sprintf(buffer, "%g/%g ", d_eff[i], d[i]);
-      else sprintf(buffer, "%g ", d[i]);
+      if(b[i] == 0.0) snprintf(buffer, BUFFMAX, "%g/%g ", d_eff[i], d[i]);
+      else snprintf(buffer, BUFFMAX, "%g ", d[i]);
       s.append(buffer);
     }
     
     /* do the same for the last d, and then close it off */
-    if(b[dim-1] == 0.0) sprintf(buffer, "%g/%g]", d_eff[dim-1], d[dim-1]);
-    else sprintf(buffer, "%g]", d[dim-1]);
+    if(b[dim-1] == 0.0) snprintf(buffer, BUFFMAX, "%g/%g]", d_eff[dim-1], d[dim-1]);
+    else snprintf(buffer, BUFFMAX, "%g]", d[dim-1]);
   }
   s.append(buffer);
 
 #ifdef PRINTNUG
   /* print the nugget */
-  sprintf(buffer, ", g=%g)", nug);
+  snprintf(buffer, BUFFMAX, ", g=%g)", nug);
   s.append(buffer);
 #endif
   
@@ -814,13 +813,13 @@ char** ExpSep::TraceNames(unsigned int* len)
   /* copy the d-vector of range parameters */
   for(unsigned int i=0; i<dim; i++) {
     trace[1+i] = (char*) malloc(sizeof(char) * (3 + (dim)/10 + 1));
-    sprintf(trace[1+i], "d%d", i+1);
+    snprintf(trace[1+i], (3 + (dim)/10 + 1), "d%d", i+1);
   }
 
   /* copy the booleans */
   for(unsigned int i=0; i<dim; i++) {
     trace[1+dim+i] = (char*) malloc(sizeof(char) * (3 + (dim) + 1));
-    sprintf(trace[1+dim+i], "b%d", i+1);
+    snprintf(trace[1+dim+i], (3 + (dim) + 1), "b%d", i+1);
   }
 
   /* determinant of K */
@@ -830,6 +829,21 @@ char** ExpSep::TraceNames(unsigned int* len)
 }
 
 
+void ExpSep::Invert(unsigned int n)
+{
+
+  if(! linear) {
+    assert(n == this->n);
+    inverse_chol(K, Ki, Kchol, n);
+    log_det_K = log_determinant_chol(Kchol, n);
+  }
+  else {
+    assert(n > 0);
+    log_det_K = n * log(1.0 + nug);
+  }
+}
+
+
 /*
  * ExpSep_Prior:
  *
@@ -939,8 +953,8 @@ void ExpSep_Prior::read_double(double *dparams)
 
   /* read the starting value(s) for the range parameter(s) */
   for(unsigned int i=0; i<dim; i++) d[i] = dparams[1];
-  /*myprintf(stdout, "starting d=");
-    printVector(d, dim, stdout, HUMAN); */
+  /*MYprintf(MYstdout, "starting d=");
+    printVector(d, dim, MYstdout, HUMAN); */
 
   /* reset the d parameter to after nugget and gamlin params */
   dparams += 13;
@@ -956,7 +970,7 @@ void ExpSep_Prior::read_double(double *dparams)
 
   /* d hierarchical lambda prior parameters */
   if((int) dparams[0] == -1)
-    { fix_d = true; /*myprintf(stdout, "fixing d prior\n");*/ }
+    { fix_d = true; /*MYprintf(MYstdout, "fixing d prior\n");*/ }
   else {
     fix_d = false;
     get_mix_prior_params_double(d_alpha_lambda, d_beta_lambda, dparams, "d lambda");
@@ -983,8 +997,8 @@ void ExpSep_Prior::read_ctrlfile(ifstream *ctrlfile)
   ctrlfile->getline(line, BUFFMAX);
   d[0] = atof(strtok(line, " \t\n#"));
   for(unsigned int i=1; i<dim; i++) d[i] = d[0];
-  myprintf(stdout, "starting d=", d);
-  printVector(d, dim, stdout, HUMAN);
+  MYprintf(MYstdout, "starting d=", d);
+  printVector(d, dim, MYstdout, HUMAN);
 
   /* read d and nug-hierarchical parameters (mix of gammas) */
   double alpha[2], beta[2];
@@ -999,7 +1013,7 @@ void ExpSep_Prior::read_ctrlfile(ifstream *ctrlfile)
   ctrlfile->getline(line, BUFFMAX);
   strcpy(line_copy, line);
   if(!strcmp("fixed", strtok(line_copy, " \t\n#")))
-    { fix_d = true; myprintf(stdout, "fixing d prior\n"); }
+    { fix_d = true; MYprintf(MYstdout, "fixing d prior\n"); }
   else {
     fix_d = false;
     get_mix_prior_params(d_alpha_lambda, d_beta_lambda, line, "d lambda");  
@@ -1239,29 +1253,29 @@ void ExpSep_Prior::SetBasePrior(Base_Prior *base_prior)
 
 void ExpSep_Prior::Print(FILE *outfile)
 {
-  myprintf(stdout, "corr prior: separable power\n");
+  MYprintf(MYstdout, "corr prior: separable power\n");
 
   /* print nugget stuff first */
   PrintNug(outfile);
 
   /* range parameter */
-  /* myprintf(outfile, "starting d=\n");
+  /* MYprintf(outfile, "starting d=\n");
      printVector(d, dim, outfile, HUMAN); */
 
   /* range gamma prior, just print once */
-  myprintf(outfile, "d[a,b][0,1]=[%g,%g],[%g,%g]\n",
+  MYprintf(outfile, "d[a,b][0,1]=[%g,%g],[%g,%g]\n",
 	   d_alpha[0][0], d_beta[0][0], d_alpha[0][1], d_beta[0][1]);
 
   /* print many times, one for each dimension instead? */
   /* for(unsigned int i=1; i<dim; i++) {
-       myprintf(outfile, "d[a,b][%d][0,1]=[%g,%g],[%g,%g]\n", i,
+       MYprintf(outfile, "d[a,b][%d][0,1]=[%g,%g],[%g,%g]\n", i,
 	     d_alpha[i][0], d_beta[i][0], d_alpha[i][1], d_beta[i][1]);
 	     } */
  
   /* range gamma hyperprior */
-  if(fix_d) myprintf(outfile, "d prior fixed\n");
+  if(fix_d) MYprintf(outfile, "d prior fixed\n");
   else {
-    myprintf(stdout, "d lambda[a,b][0,1]=[%g,%g],[%g,%g]\n", 
+    MYprintf(MYstdout, "d lambda[a,b][0,1]=[%g,%g],[%g,%g]\n", 
 	     d_alpha_lambda[0], d_beta_lambda[0], d_alpha_lambda[1], 
 	     d_beta_lambda[1]);
   }
@@ -1313,13 +1327,13 @@ char** ExpSep_Prior::TraceNames(unsigned int* len)
 
   for(unsigned int i=0,j=0; i<dim; i++, j+=4) {
     trace[j] = (char*) malloc(sizeof(char) * (5+(dim)/10 + 1));
-    sprintf(trace[j], "d%d.a0", i);
+    snprintf(trace[j], (5+(dim)/10 + 1), "d%d.a0", i);
     trace[j+1] = (char*) malloc(sizeof(char) * (5+(dim)/10 + 1));
-    sprintf(trace[j+1], "d%d.g0", i);
+    snprintf(trace[j+1], (5+(dim)/10 + 1), "d%d.g0", i);
     trace[j+2] = (char*) malloc(sizeof(char) * (5+(dim)/10 + 1));
-    sprintf(trace[j+2], "d%d.a1", i);
+    snprintf(trace[j+2], (5+(dim)/10 + 1), "d%d.a1", i);
     trace[j+3] = (char*) malloc(sizeof(char) * (5+(dim)/10 + 1));
-    sprintf(trace[j+3], "d%d.g1", i);
+    snprintf(trace[j+3], (5+(dim)/10 + 1), "d%d.g1", i);
   }
 
   /* then copy in the nug trace */
