@@ -21,6 +21,7 @@
  *
  ********************************************************************************/
 
+#include "rhelp.h"
 
 extern "C"
 {
@@ -30,7 +31,6 @@ extern "C"
 #include "rand_pdf.h"
 #include "all_draws.h"
 #include "gen_covar.h"
-#include "rhelp.h"
 }
 #include "corr.h"
 #include "params.h"
@@ -446,11 +446,11 @@ char* Matern::State(unsigned int which)
 #else
   string s = "";
 #endif
-  if(linear) sprintf(buffer, "0(%g)", d);
-  else sprintf(buffer, "%g", d);
+  if(linear) snprintf(buffer, BUFFMAX, "0(%g)", d);
+  else snprintf(buffer, BUFFMAX, "%g", d);
   s.append(buffer);
 #ifdef PRINTNUG
-  sprintf(buffer, ", g=%g)", nug);
+  snprintf(buffer, BUFFMAX, ", g=%g)", nug);
   s.append(buffer);
 #endif
   
@@ -575,6 +575,20 @@ double* Matern::Trace(unsigned int* len)
   return trace;
 }
 
+void Matern::Invert(unsigned int n)
+{
+
+  if(! linear) {
+    assert(n == this->n);
+    inverse_chol(K, Ki, Kchol, n);
+    log_det_K = log_determinant_chol(Kchol, n);
+  }
+  else {
+    assert(n > 0);
+    log_det_K = n * log(1.0 + nug);
+  }
+}
+
 
 /*
  * newCorr:
