@@ -21,7 +21,10 @@
  *
  ********************************************************************************/
 
+#include "rhelp.h"
 
+#include <Rmath.h>
+#include <R.h>
 extern "C"
 {
 #include "lh.h"
@@ -30,8 +33,6 @@ extern "C"
 #include "rand_draws.h"
 #include "rand_pdf.h"
 #include "gen_covar.h"
-#include "rhelp.h"
-#include <Rmath.h>
 }
 #include "model.h"
 #include <stdlib.h>
@@ -66,7 +67,7 @@ Model::Model(Params* params, unsigned int d, double** rect, int Id, bool trace,
 #ifdef PARALLEL 
   parallel = true;
   if(RNG == CRAN && NUMTHREADS > 1)
-    warning("using thread unsafe unif_rand() with pthreads");
+    Rf_warning("using thread unsafe unif_rand() with pthreads");
 #else
   parallel = false;
 #endif
@@ -75,7 +76,7 @@ Model::Model(Params* params, unsigned int d, double** rect, int Id, bool trace,
   if(parallel) { init_parallel_preds(); consumer_start(); }
   
   /* stuff to do with printing */
-  OUTFILE = mystdout;
+  OUTFILE = MYstdout;
   verb = 2;
   this->trace = trace;
 
@@ -88,7 +89,7 @@ Model::Model(Params* params, unsigned int d, double** rect, int Id, bool trace,
 
   /* asynchronous writing to files by multiple threads is problematic */
   if(trace && parallel) 
-      warning("traces in parallel version of tgp not recommended\n");
+      Rf_warning("traces in parallel version of tgp not recommended\n");
   
   /* initialize tree operation statistics */
   swap = prune = change = grow = swap_try = change_try = grow_try = prune_try = 0;
@@ -346,7 +347,7 @@ void Model::rounds(Preds *preds, unsigned int B, unsigned int T, void *state)
     free(leaves); 
 
     /* periodically check R for interrupts and flush console every second */
-    itime = my_r_process_events(itime);
+    itime = MY_r_process_events(itime);
   }
   
   /* send a full set of leaves out for prediction */
@@ -468,7 +469,7 @@ bool Model::modify_tree(void *state)
   case 2: /* prune */ return prune_tree(state);
   case 3: /* change */ return change_tree(state);
   case 4: /* swap */ return swap_tree(state);
-  default: error("action %d not supported", action);
+  default: Rf_error("action %d not supported", action);
   }
 
   /* should not reach here */
@@ -638,10 +639,10 @@ void Model::cut_branch(void *state)
   unsigned int k = (unsigned int) sample_seq(0,len,state);
   if(k == len) { 
     if(verb >= 1) 
-      myprintf(OUTFILE, "tree unchanged (no branches removed)\n");
+      MYprintf(OUTFILE, "tree unchanged (no branches removed)\n");
   } else {
     if(verb >= 1) 
-      myprintf(OUTFILE, "removed %d leaves from the tree\n", nodes[k]->numLeaves());
+      MYprintf(OUTFILE, "removed %d leaves from the tree\n", nodes[k]->numLeaves());
     nodes[k]->cut_branch();
   }
   free(nodes);
@@ -659,10 +660,10 @@ void Model::cut_root(void)
 { 
   if(t->isLeaf()) {
     if(verb >= 1)
-      myprintf(OUTFILE, "removed 0 leaves from the tree\n");
+      MYprintf(OUTFILE, "removed 0 leaves from the tree\n");
   } else {
     if(verb >= 1) 
-      myprintf(OUTFILE, "removed %d leaves from the tree\n", t->numLeaves());
+      MYprintf(OUTFILE, "removed %d leaves from the tree\n", t->numLeaves());
   }
   t->cut_branch();
 }
@@ -720,11 +721,11 @@ void Model::new_data(double **X, unsigned int n, unsigned int d, double* Z, doub
 
 void Model::PrintTreeStats(FILE* outfile)
 {
-  if(grow_try > 0) myprintf(outfile, "Grow: %.4g%c, ", 100* (double)grow/grow_try, '%');
-  if(prune_try > 0) myprintf(outfile, "Prune: %.4g%c, ", 100* (double)prune/prune_try, '%');
-  if(change_try > 0) myprintf(outfile, "Change: %.4g%c, ", 100* (double)change/change_try, '%');
-  if(swap_try > 0) myprintf(outfile, "Swap: %.4g%c", 100* (double)swap/swap_try, '%');
-  if(grow_try > 0) myprintf(outfile, "\n");
+  if(grow_try > 0) MYprintf(outfile, "Grow: %.4g%c, ", 100* (double)grow/grow_try, '%');
+  if(prune_try > 0) MYprintf(outfile, "Prune: %.4g%c, ", 100* (double)prune/prune_try, '%');
+  if(change_try > 0) MYprintf(outfile, "Change: %.4g%c, ", 100* (double)change/change_try, '%');
+  if(swap_try > 0) MYprintf(outfile, "Swap: %.4g%c", 100* (double)swap/swap_try, '%');
+  if(grow_try > 0) MYprintf(outfile, "\n");
 }
 
 
@@ -831,47 +832,47 @@ void Model::PrintState(unsigned int r, unsigned int numLeaves, Tree** leaves)
   /* print round information */
 #ifdef PARALLEL
   if(num_produced - num_consumed > 0)
-    myprintf(OUTFILE, "(r,l)=(%d,%d) ", r, num_produced - num_consumed);
-  else myprintf(OUTFILE, "r=%d ", r);
+    MYprintf(OUTFILE, "(r,l)=(%d,%d) ", r, num_produced - num_consumed);
+  else MYprintf(OUTFILE, "r=%d ", r);
 #else
-  myprintf(OUTFILE, "r=%d ", r);
+  MYprintf(OUTFILE, "r=%d ", r);
 #endif
   
   /* this is here so that the progress meter in SampleMap doesn't need to print
      the same tree information each time */
   if(numLeaves > 0) {
 
-    // myprintf(OUTFILE, " d=");
+    // MYprintf(OUTFILE, " d=");
 
     /* print the (correllation) state (d-values and maybe nugget values) */
     for(unsigned int i=0; i<numLeaves; i++) {
       char *state = leaves[i]->State(i);
-      myprintf(OUTFILE, "%s", state);
-      if(i != numLeaves-1) myprintf(OUTFILE, " ");
+      MYprintf(OUTFILE, "%s", state);
+      if(i != numLeaves-1) MYprintf(OUTFILE, " ");
       free(state);
     }
     
     /* a delimeter */
-    myprintf(OUTFILE, "; ");
+    MYprintf(OUTFILE, "; ");
     
     /* print maximum posterior prob tree height */
     Tree *maxt = maxPosteriors();
-    if(maxt) myprintf(OUTFILE, "mh=%d ", maxt->Height());
+    if(maxt) MYprintf(OUTFILE, "mh=%d ", maxt->Height());
     
     /* print partition sizes */
-    if(numLeaves > 1) myprintf(OUTFILE, "n=(");
-    else myprintf(OUTFILE, "n=");
+    if(numLeaves > 1) MYprintf(OUTFILE, "n=(");
+    else MYprintf(OUTFILE, "n=");
     for(unsigned int i=0; i<numLeaves-1; i++)
-      myprintf(OUTFILE, "%d,", leaves[i]->getN());
-    if(numLeaves > 1) myprintf(OUTFILE, "%d)", leaves[numLeaves-1]->getN());
-    else myprintf(OUTFILE, "%d", leaves[numLeaves-1]->getN());
+      MYprintf(OUTFILE, "%d,", leaves[i]->getN());
+    if(numLeaves > 1) MYprintf(OUTFILE, "%d)", leaves[numLeaves-1]->getN());
+    else MYprintf(OUTFILE, "%d", leaves[numLeaves-1]->getN());
     
   }
 
   /* cap off the printing */
-  if(its->Numit() > 1) myprintf(OUTFILE, " k=%g", its->Itemp());
-  myprintf(OUTFILE, "\n");
-  myflush(OUTFILE);  
+  if(its->Numit() > 1) MYprintf(OUTFILE, " k=%g", its->Itemp());
+  MYprintf(OUTFILE, "\n");
+  MYflush(OUTFILE);  
 }
 
 
@@ -924,7 +925,7 @@ void Model::close_parallel_preds(void)
   delete PP; PP = NULL;
 
 #else
-  error("close_parallel_preds: not compiled for pthreads");
+  Rf_error("close_parallel_preds: not compiled for pthreads");
 #endif
 }
 
@@ -960,7 +961,7 @@ void Model::init_parallel_preds(void)
   num_consumed = num_produced = 0;
   
 #else
-  error("init_parallel_preds: not compiled for pthreads\n");
+  Rf_error("init_parallel_preds: not compiled for pthreads\n");
 #endif
 }
 
@@ -983,7 +984,7 @@ void Model::predict_producer(Tree *leaf, Preds *preds, int index, bool dnorm)
   num_produced++;
   PP->EnQueue((void*) largs);
 #else
-  error("predict_producer: not compiled for pthreads");
+  Rf_error("predict_producer: not compiled for pthreads");
 #endif
 }
 
@@ -1009,7 +1010,7 @@ void Model::produce(void)
   pthread_mutex_unlock(l_mut);
   pthread_cond_signal(l_cond_nonempty);
 #else
-  error("produce: not compiled for pthreads");
+  Rf_error("produce: not compiled for pthreads");
 #endif
 }
 
@@ -1089,7 +1090,7 @@ void Model::predict_consumer(void)
   }
   
 #else
-  error("predict_consumer: not compiled for pthreads");
+  Rf_error("predict_consumer: not compiled for pthreads");
 #endif
 }
 
@@ -1097,7 +1098,7 @@ void Model::predict_consumer(void)
 /*
  * predict_consumer_c:
  * 
- * a dummy c-style function that calls the
+ * a dumMY c-style function that calls the
  * consumer function from the Model class
  */
 
@@ -1129,7 +1130,7 @@ void Model::consumer_finish(void)
     pthread_join(*consumer[i], NULL);
   }
 #else
-  error("consumer_finish: not compiled for pthreads");
+  Rf_error("consumer_finish: not compiled for pthreads");
 #endif
 }
 
@@ -1146,10 +1147,11 @@ void Model::consumer_start(void)
   int success;
   for(unsigned int i=0; i<NUMTHREADS; i++) {
     success = pthread_create(consumer[i], NULL, predict_consumer_c, (void*) this);
+    if(!success) Rf_error("could not create pthread");
     assert(success == 0);
   }
 #else
-  error("consumer_start: not compiled for pthreads");
+  Rf_error("consumer_start: not compiled for pthreads");
 #endif
 }
 
@@ -1174,8 +1176,8 @@ void Model::wrap_up_predictions(void)
       tlen = tlist->Len();
       diff = num_produced - num_consumed;
       if(verb >= 1) {
-        myprintf(OUTFILE, "waiting for (%d, %d) predictions\n", tlen, diff); 
-        myflush(OUTFILE); 
+        MYprintf(OUTFILE, "waiting for (%d, %d) predictions\n", tlen, diff); 
+        MYflush(OUTFILE); 
       }
     }
     pthread_mutex_unlock(l_mut);
@@ -1184,7 +1186,7 @@ void Model::wrap_up_predictions(void)
   pthread_mutex_unlock(l_mut);
   num_consumed = num_produced = 0;
 #else
-  error("wrap_up_predictions: not compiled for pthreads");
+  Rf_error("wrap_up_predictions: not compiled for pthreads");
 #endif
 }
 
@@ -1220,10 +1222,11 @@ Tree** Model::CopyPartitions(unsigned int *numLeaves)
 void Model::MAPreplace(void)
 {
   Tree* maxt = maxPosteriors();
-  assert(maxt);
-  if(t) delete t;
-  t = new Tree(maxt, true);
-  
+  if(maxt) {
+    if(t) delete t;
+    t = new Tree(maxt, true);
+  } else maxt = t;
+
   /* get leaves ready for use */
   unsigned int len;
   Tree** leaves = t->leavesList(&len);
@@ -1248,7 +1251,7 @@ void Model::PrintBestPartitions()
   FILE *BESTPARTS;
   Tree *maxt = maxPosteriors();
   if(!maxt) {
-    warning("not enough MCMC rounds for MAP tree, using current");
+    Rf_warning("not enough MCMC rounds for MAP tree, using current");
     maxt = t;
   }
   assert(maxt);
@@ -1365,7 +1368,7 @@ double Model::Partitions(void)
 FILE* Model::OpenFile(const char *prefix, const char *type)
 {
   char outfile_str[BUFFMAX];
-  sprintf(outfile_str, "%s_%s_%d.out", prefix, type, Id+1);
+  snprintf(outfile_str, BUFFMAX, "%s_%s_%d.out", prefix, type, Id+1);
   FILE* OFILE = fopen(outfile_str, "w");
   assert(OFILE);
   return OFILE;
@@ -1380,11 +1383,11 @@ FILE* Model::OpenFile(const char *prefix, const char *type)
 void Model::PrintTree(FILE* outfile)
 {
   assert(outfile);
-  myprintf(outfile, "rows var n dev yval splits.cutleft splits.cutright ");
+  MYprintf(outfile, "rows var n dev yval splits.cutleft splits.cutright ");
 
   /* the following are for printing a higher precision val, and base model
      parameters for reconstructing trees later */
-  myprintf(outfile, "val ");
+  MYprintf(outfile, "val ");
   TraceNames(outfile, true);
   this->t->PrintTree(outfile, iface_rect, NORMSCALE, 1);
 }
@@ -1425,7 +1428,7 @@ void Model::DrawInvTemp(void* state, bool burnin)
   //double diff_post = pnew - p;
   double diff_lik =  llnew - ll;
 
-  //myprintf(mystderr, "diff=%g\n", diff_post-diff_lik);
+  //MYprintf(MYstderr, "diff=%g\n", diff_post-diff_lik);
   //assert(diff_post == diff_lik);
 
   /* add in the priors for the itemp (weights) */
@@ -1486,14 +1489,14 @@ double Model::Posterior(bool record)
     /* allocate the trace files for printing posteriors*/   
     if(!POSTTRACEFILE) {
       POSTTRACEFILE = OpenFile("trace", "post");
-      myprintf(POSTTRACEFILE, "height leaves lpost itemp tlpost w\n");
+      MYprintf(POSTTRACEFILE, "height leaves lpost itemp tlpost w\n");
     }
 
     /* write a line to the file recording the trace of the posteriors */
-    myprintf(POSTTRACEFILE, "%d %d %15f %15f %15f %15f\n", 
+    MYprintf(POSTTRACEFILE, "%d %d %15f %15f %15f %15f\n", 
 	     t->Height(), t->numLeaves(), full_post, its->Itemp(), 
 	     full_post_temp, w);
-    myflush(POSTTRACEFILE);
+    MYflush(POSTTRACEFILE);
   }
 
   return w;
@@ -1513,9 +1516,9 @@ void Model::PrintPosteriors(void)
   char filestr[MEDBUFF];
 
   /* open a file to write the posterior information to */
-  sprintf(filestr, "tree_m%d_posts.out", Id);
+  snprintf(filestr, BUFFMAX, "tree_m%d_posts.out", Id);
   FILE *postsfile = fopen(filestr, "w");
-  myprintf(postsfile, "height lpost ");
+  MYprintf(postsfile, "height lpost ");
   PriorTraceNames(postsfile, true);
 
   /* unsigned int t_minpart, t_splitmin;
@@ -1526,15 +1529,15 @@ void Model::PrintPosteriors(void)
     if(posteriors->trees[i] == NULL) continue;
 
     /* open a file to write the tree to */
-    sprintf(filestr, "tree_m%d_%d.out", Id, i+1);
+    snprintf(filestr, BUFFMAX, "tree_m%d_%d.out", Id, i+1);
     FILE *treefile = fopen(filestr, "w");
 
     /* add maptree-relevant headers */
-    myprintf(treefile, "rows var n dev yval splits.cutleft splits.cutright ");
+    MYprintf(treefile, "rows var n dev yval splits.cutleft splits.cutright ");
 
     /* the following are for printing a higher precision val, and base model
      parameters for reconstructing trees later */
-    myprintf(treefile, "val ");
+    MYprintf(treefile, "val ");
 
     /* add parameter trace relevant headers */
     TraceNames(treefile, true);
@@ -1545,7 +1548,7 @@ void Model::PrintPosteriors(void)
 
     /* add information about height and posteriors to file */
     assert(i+1 == posteriors->trees[i]->Height());
-    myprintf(postsfile, "%d %g ", posteriors->trees[i]->Height(), posteriors->posts[i]);
+    MYprintf(postsfile, "%d %g ", posteriors->trees[i]->Height(), posteriors->posts[i]);
     
     /* add prior parameter trace information to the posts file */
     unsigned int tlen;
@@ -1566,7 +1569,7 @@ void Model::PrintPosteriors(void)
 Tree* Model::maxPosteriors(void)
 {
   Tree *maxt = NULL;
-  double maxp = -1e300*1e300;
+  double maxp = R_NegInf;
 
   for(unsigned int i=0; i<posteriors->maxd; i++) {
     if(posteriors->trees[i] == NULL) continue;
@@ -1640,7 +1643,7 @@ void Model::Linburn(unsigned int B, void *state)
 {
   double gam = Linear();
   //if(gam) {
-    if(verb > 0) myprintf(OUTFILE, "\nlinear model init:\n");
+    if(verb > 0) MYprintf(OUTFILE, "\nlinear model init:\n");
     rounds(NULL, B, B, state);
     ResetLinear(gam);
   //}
@@ -1655,7 +1658,7 @@ void Model::Linburn(unsigned int B, void *state)
 
 void Model::Burnin(unsigned int B, void *state)
 {
-  if(verb >= 1 && B>0) myprintf(OUTFILE, "\nburn in:\n");
+  if(verb >= 1 && B>0) MYprintf(OUTFILE, "\nburn in:\n");
   rounds(NULL, B, B, state);
 }
 
@@ -1672,7 +1675,7 @@ void Model::StochApprox(unsigned int B, void *state)
 {
   if(!its->DoStochApprox()) return;
   if(verb >= 1 && B>0) 
-    myprintf(OUTFILE, "\nburn in: [with stoch approx (c0,n0)=(%g,%g)]\n",
+    MYprintf(OUTFILE, "\nburn in: [with stoch approx (c0,n0)=(%g,%g)]\n",
 	     its->C0(), its->N0());
 
   /* do the rounds of stochastic approximation */
@@ -1697,9 +1700,9 @@ void Model::Sample(Preds *preds, unsigned int R, void *state)
   if(R == 0) return;
 
   if(verb >= 1 && R>0) {
-    myprintf(OUTFILE, "\nSampling @ nn=%d pred locs:", preds->nn);
-    if(trace) myprintf(OUTFILE, " [with traces]");
-    myprintf(OUTFILE, "\n");
+    MYprintf(OUTFILE, "\nSampling @ nn=%d pred locs:", preds->nn);
+    if(trace) MYprintf(OUTFILE, " [with traces]");
+    MYprintf(OUTFILE, "\n");
   }
 		       
   rounds(preds, 0, R, state);
@@ -1718,7 +1721,7 @@ void Model::Predict(Preds *preds, unsigned int R, void *state)
   if(R == 0) return;
   assert(preds);
 
-  if(verb >=1) myprintf(OUTFILE, "\nKriging @ nn=%d predictive locs:\n", preds->nn);
+  if(verb >=1) MYprintf(OUTFILE, "\nKriging @ nn=%d predictive locs:\n", preds->nn);
 
   /* get leaves of the tree */
   unsigned int numLeaves;
@@ -1744,7 +1747,7 @@ void Model::Predict(Preds *preds, unsigned int R, void *state)
 	sens_sample(preds->XX, preds->nn, preds->d, preds->bnds, preds->shape, 
 		    preds->mode, state); 
 	dupv(preds->M[r/preds->mult], preds->XX[0], preds->d * preds->nm);
-	//printf("xx: \n"); printMatrix(preds->XX, preds->nn, preds->d, mystdout);
+	//printf("xx: \n"); printMatrix(preds->XX, preds->nn, preds->d, MYstdout);
 	normalize(preds->XX, preds->rect, preds->nn, preds->d, 1.0);
       }
 
@@ -1761,7 +1764,7 @@ void Model::Predict(Preds *preds, unsigned int R, void *state)
     }
 
     /* periodically check R for interrupts and flush console every second */
-    itime = my_r_process_events(itime);
+    itime = MY_r_process_events(itime);
   }
 
   /* clean up */
@@ -1806,10 +1809,10 @@ void Model::TraceNames(FILE * outfile, bool full)
   unsigned int len;
   char **trace_names = t->TraceNames(&len, full);
   for(unsigned int i=0; i<len; i++) {
-    myprintf(outfile, "%s ", trace_names[i]);
+    MYprintf(outfile, "%s ", trace_names[i]);
     free(trace_names[i]);
   }
-  myprintf(outfile, "\n");
+  MYprintf(outfile, "\n");
   free(trace_names);
 }
 
@@ -1828,10 +1831,10 @@ void Model::PriorTraceNames(FILE * outfile, bool full)
   unsigned int len;
   char **trace_names = base_prior->TraceNames(&len, full);
   for(unsigned int i=0; i<len; i++) {
-    myprintf(outfile, "%s ", trace_names[i]);
+    MYprintf(outfile, "%s ", trace_names[i]);
     free(trace_names[i]);
   }
-  myprintf(outfile, "\n");
+  MYprintf(outfile, "\n");
   free(trace_names);
 }
 
@@ -1859,13 +1862,13 @@ void Model::Trace(Tree *leaf, unsigned int index)
   if(!XXTRACEFILE) {
     /* trace of GP parameters for each XX input location */
     XXTRACEFILE = OpenFile("trace", "XX");
-    myprintf(XXTRACEFILE, "ppi index ");
+    MYprintf(XXTRACEFILE, "ppi index ");
     TraceNames(XXTRACEFILE, false);
   }
 
   /* actual printing of trace for a tree leaf */
   leaf->Trace(index, XXTRACEFILE);
-  myflush(XXTRACEFILE);
+  MYflush(XXTRACEFILE);
 
   /* unlock */
 #ifdef PARALLEL
