@@ -23,6 +23,8 @@
  ********************************************************************************/
 
 
+#include "R.h"
+
 extern "C" {
 #include "rand_draws.h"
 #include "matrix.h"
@@ -30,7 +32,6 @@ extern "C" {
 }
 #include "temper.h"
 #include <stdlib.h>
-#include <stdio.h>
 #include <assert.h>
 #include <math.h>
 
@@ -118,7 +119,7 @@ Temper::Temper(double *ditemps)
   case 1: it_lambda = OPT; break;
   case 2: it_lambda = NAIVE; break;
   case 3: it_lambda = ST; break;
-  default: error("IT lambda = %d unknown\n", dlambda);
+  default: Rf_error("IT lambda = %d unknown\n", dlambda);
   }
 
   /* init itemp-location pointer -- find closest to 1.0 */
@@ -266,7 +267,7 @@ double Temper::Propose(double *q_fwd, double *q_bak, void *state)
 {
   /* sanity check */
   if(knew != -1)
-    warning("did not accept or reject last proposed itemp");
+    Rf_warning("did not accept or reject last proposed itemp");
   
   if(k == 0) {
     
@@ -380,11 +381,11 @@ double* Temper::UpdatePrior(void)
   assert(min != 0);
 
   /* now adjust the probabilities */
-  double sum = 0.0;
+  // double sum = 0.0;
   for(unsigned int i=0; i<numit; i++) {
     if(tcounts[i] == 0) tcounts[i] = min;
     tprobs[i] /= tcounts[i];
-    sum += tprobs[i];
+    // sum += tprobs[i];
   }
 
   /* now normalize the probabilities */
@@ -473,7 +474,7 @@ double Temper::LambdaOpt(double *w, double *itemp, unsigned int wlen,
   unsigned int len;
   unsigned int tlen = 0;
   double tess = 0.0;
-  double eisum = 0.0;
+  // double eisum = 0.0;
   
   /* allocate space for the lambdas, etc */
   double *lambda = new_zero_vector(numit);
@@ -482,7 +483,7 @@ double Temper::LambdaOpt(double *w, double *itemp, unsigned int wlen,
 
   /* for pretty printing */
   if(verb >= 1)
-    myprintf(stdout, "\neffective sample sizes:\n");
+    MYprintf(MYstdout, "\neffective sample sizes:\n");
 
   /* for each temperature */
   for(unsigned int i=0; i<numit; i++) {
@@ -514,12 +515,12 @@ double Temper::LambdaOpt(double *w, double *itemp, unsigned int wlen,
       /* check for numerical problems and (if none) calculate the
          within temperature ESS */
       if(!R_FINITE(lambda[i])) {
-	lambda[i] = 0;
-	ei = 0;
+	      lambda[i] = 0;
+	      ei = 0;
       } else ei = calc_ess(wi, len);
 
       /* sum up the within temperature ESS's */
-      eisum += ei*len;
+      // eisum += ei*len;
 
     } else { W[i] = 1; } /* doesn't matter since ei=0 */
 
@@ -533,7 +534,7 @@ double Temper::LambdaOpt(double *w, double *itemp, unsigned int wlen,
 
     /* print individual ess */
     if(verb >= 1)
-      myprintf(stdout, "%d: itemp=%g, len=%d, ess=%g\n", //, sw=%g\n", 
+      MYprintf(MYstdout, "%d: itemp=%g, len=%d, ess=%g\n", //, sw=%g\n", 
 	       i, itemps[i], len, ei*len); //, sumv(wi, len));
 
     /* clean up */
@@ -570,11 +571,11 @@ double Temper::LambdaOpt(double *w, double *itemp, unsigned int wlen,
 
   /* print totals */
   if(verb >= 1) {
-    myprintf(stdout, "total: len=%d, ess.sum=%g, ess(w)=%g\n", 
+    MYprintf(MYstdout, "total: len=%d, ess.sum=%g, ess(w)=%g\n", 
 	     tlen, tess, ((double)wlen)*calc_ess(w,wlen));
     double lce = wlen*(wlen-1.0)*gamma_sum/(sq(wlen)-gamma_sum);
     if(ISNAN(lce)) lce = 1;
-    myprintf(stdout, "lambda-combined ess=%g\n", lce);
+    MYprintf(MYstdout, "lambda-combined ess=%g\n", lce);
   }
 
   /* clean up */
@@ -637,7 +638,7 @@ void Temper::EachESS(double *w, double *itemp, unsigned int wlen, double *essd)
 double Temper::LambdaST(double *w, double *itemp, unsigned int wlen, unsigned int verb)
 {
   /* ST not doable */
-  if(itemps[0] != 1.0) warning("itemps[0]=%d != 1.0", itemps[0]);
+  if(itemps[0] != 1.0) Rf_warning("itemps[0]=%g != 1.0", itemps[0]);
 
   /* get the weights at the i-th temperature */
   unsigned int len;
@@ -666,7 +667,7 @@ double Temper::LambdaST(double *w, double *itemp, unsigned int wlen, unsigned in
   copy_p_vector(w, p, wi, len);
 
   /* print totals */
-  if(verb >= 1) myprintf(stdout, "\nST sample size=%d\n", len);
+  if(verb >= 1) MYprintf(MYstdout, "\nST sample size=%d\n", len);
 
   /* return the overall effective sample size */
   return((double) len);
@@ -693,7 +694,7 @@ double Temper::LambdaNaive(double *w, unsigned int wlen, unsigned int verb)
   double ess = ((double)wlen)*calc_ess(w, wlen);
 
   /* print totals */
-  if(verb >= 1) myprintf(stdout, "\nnaive IT ess=%g\n", ess);
+  if(verb >= 1) MYprintf(MYstdout, "\nnaive IT ess=%g\n", ess);
 
   /* return the overall effective sample size */
   return(ess);
@@ -850,7 +851,7 @@ double Temper::LambdaIT(double *w, double *itemp, unsigned int R, double *essd,
   case OPT: ess = LambdaOpt(w, itemp, R, essd, verb); break;
   case NAIVE: ess = LambdaNaive(w, R, verb); EachESS(w, itemp, R, essd); break;
   case ST: ess = LambdaST(w, itemp, R, verb); EachESS(w, itemp, R, essd); break;
-  default: error("bad it_lambda\n");
+  default: Rf_error("bad it_lambda\n");
   }
 
   return ess;
@@ -867,16 +868,16 @@ double Temper::LambdaIT(double *w, double *itemp, unsigned int R, double *essd,
 void Temper::Print(FILE *outfile)
 {
   /* print the importance tempring information */
-  if(IS()) myprintf(outfile, "IS with inv-temp %g\n", itemps[0]);
+  if(IS()) MYprintf(outfile, "IS with inv-temp %g\n", itemps[0]);
   else if(IT_or_ST()) {
     switch(it_lambda) {
-    case OPT: myprintf(outfile, "IT: optimal"); break;
-    case NAIVE: myprintf(outfile, "IT: naive"); break;
-    case ST: myprintf(outfile, "IT: implementing ST"); break;
+    case OPT: MYprintf(outfile, "IT: optimal"); break;
+    case NAIVE: MYprintf(outfile, "IT: naive"); break;
+    case ST: MYprintf(outfile, "IT: implementing ST"); break;
     }
-    myprintf(outfile, " on %d-rung ladder\n", numit);
-    if(DoStochApprox()) myprintf(outfile, "    with stoch approx\n");
-    else myprintf(outfile, "\n");
+    MYprintf(outfile, " on %d-rung ladder\n", numit);
+    if(DoStochApprox()) MYprintf(outfile, "    with stoch approx\n");
+    else MYprintf(outfile, "\n");
   }
 }
 
@@ -925,7 +926,7 @@ double calc_ess(double *w, unsigned int n)
   else {
     double cv2 = calc_cv2(w,n);
     if(ISNAN(cv2) || !R_FINITE(cv2)) {
-      // warning("nan or inf found in cv2, probably due to zero weights");
+      // Rf_warning("nan or inf found in cv2, probably due to zero weights");
       return 0.0;
     } else return(1.0/(1.0+cv2));
   }
