@@ -21,12 +21,12 @@
  *
  ********************************************************************************/
 
+#include "rhelp.h"
 
 extern "C"
 {
 #include "matrix.h"
 #include "rand_draws.h"  
-#include "rhelp.h"
 #include "predict.h"
 }
 #include "tgp.h"
@@ -51,10 +51,13 @@ void tgp(int* state_in,
 	 /* inputs from R */
 	 double *X_in, int *n_in, int *d_in, double *Z_in, double *XX_in, int *nn_in,
 	 double *Xsplit_in, int *nsplit_in, int *trace_in, int *BTE_in, int* R_in, 
-	 int* linburn_in, int *zcov_in, int *improv_in, double *params_in, 
+	 int* linburn_in, int *zcov_in, int *g_in, double *params_in, 
 	 double *ditemps_in, int *verb_in, double *dtree_in, double* hier_in, 
 	 int *MAP_in, int *sens_ngrid, double *sens_span, double *sens_Xgrid_in,  
 
+	 /* output dimensions for checking NULL */
+	 int* predn_in, int* nnprime_in, int *krige_in, int* Ds2x_in, int *improv_in,
+
 	 /* outputs to R */
 	 double *Zp_mean_out, double *ZZ_mean_out, double *Zp_km_out, 
 	 double *ZZ_km_out, double *Zp_kvm_out, double *ZZ_kvm_out, double *Zp_q_out, 
@@ -70,30 +73,39 @@ void tgp(int* state_in,
   unsigned int lstate = three2lstate(state_in);
   tgp_state = newRNGstate(lstate);
 
-  /* check that the improv input agrees with improv output */
-  if(*improv_in) assert(improv_out != NULL);
+  /* possibly create NULL pointers that couldn't be passed by .C -- not sure if all are needed */
+  if(dtree_in[0] < 0) dtree_in = NULL;
+  if(hier_in[0] < 0) hier_in = NULL;
+  if((*predn_in * *n_in) == 0) 
+    Zp_q1_out = Zp_q_out = Zp_q2_out = Zp_median_out = Zp_mean_out = NULL;
+  if(*nnprime_in == 0)
+    ZZ_q1_out = ZZ_q_out = ZZ_q2_out = ZZ_median_out = ZZ_mean_out = NULL;
+  if((*krige_in * *predn_in * *n_in) == 0) Zp_km_out = Zp_kvm_out = Zp_ks2_out = NULL;
+  if((*krige_in * *nnprime_in) == 0) ZZ_km_out = ZZ_kvm_out = ZZ_ks2_out = NULL;
+  if((*Ds2x_in * *nnprime_in) == 0) Ds2x_out = NULL;
+  if((*improv_in * *nnprime_in) == 0) { improv_out = NULL; irank_out = NULL; }
 
   /* copy the input parameters to the tgp class object where all the MCMC 
      work gets done */
   tgpm = new Tgp(tgp_state, *n_in, *d_in, *nn_in, BTE_in[0], BTE_in[1], BTE_in[2], *R_in, 
 		 *linburn_in, (bool) (Zp_mean_out!=NULL), 
 		 (bool) ((Zp_ks2_out!=NULL) || (ZZ_ks2_out!=NULL)), (bool) (Ds2x_out!=NULL), 
-		 improv_in[0], (bool) (*sens_ngrid > 0), X_in, Z_in, XX_in, Xsplit_in,
+		 g_in[0], (bool) (*sens_ngrid > 0), X_in, Z_in, XX_in, Xsplit_in,
 		 *nsplit_in, params_in, ditemps_in, (bool) *trace_in, *verb_in, dtree_in, 
 		 hier_in);
   
   /* post constructor initialization */
   tgpm->Init();
-  
+
   /* tgp MCMC rounds are done here */
   if(*MAP_in) tgpm->Predict();
   else tgpm->Rounds();
 
   /* gather the posterior predictive statistics from the MCMC rounds */
   tgpm->GetStats(!((bool)*MAP_in), Zp_mean_out, ZZ_mean_out, Zp_km_out, ZZ_km_out, Zp_kvm_out, 
-		 ZZ_kvm_out, Zp_q_out, ZZ_q_out, (bool) (*zcov_in), Zp_s2_out, ZZ_s2_out, ZpZZ_s2_out, 
-		 Zp_ks2_out, ZZ_ks2_out, Zp_q1_out, Zp_median_out, Zp_q2_out, ZZ_q1_out, 
-		 ZZ_median_out, ZZ_q2_out, Ds2x_out, improv_out, improv_in[1], irank_out, 
+		 ZZ_kvm_out, Zp_q_out, ZZ_q_out, (bool) (*zcov_in), Zp_s2_out, ZZ_s2_out,
+		 ZpZZ_s2_out, Zp_ks2_out, ZZ_ks2_out, Zp_q1_out, Zp_median_out, Zp_q2_out, 
+		 ZZ_q1_out, ZZ_median_out, ZZ_q2_out, Ds2x_out, improv_out, g_in[1], irank_out, 
 		 ess_out);
 
   /* sensitivity analysis? */
@@ -248,7 +260,7 @@ void Tgp::Init(void)
   /* use default parameters */
   params = new Params(d);
   if((int) dparams[0] != -1) params->read_double(dparams);
-  else myprintf(mystdout, "Using default params.\n");
+  else MYprintf(MYstdout, "Using default params.\n");
 
   /* get  the rectangle */
   /* rect = getXdataRect(X, n, d, XX, nn); */
@@ -258,14 +270,14 @@ void Tgp::Init(void)
   /* construct the new model */
   model = new Model(params, d, rect, 0, trace, state);
   model->Init(X, n, d, Z, its, tree, treecol, hier);
-  model->Outfile(mystdout, verb);
+  model->Outfile(MYstdout, verb);
 
   /* if treed partitioning is allowed, then set the splitting locations (Xsplit) */
   if(params->isTree()) model->set_Xsplit(Xsplit, nsplit, d);
 
   /* structure for accumulating predictive information */
   cump = new_preds(XX, nn, pred_n*n, d, rect, R*(T-B), pred_n, krige, 
-		       its->IT_ST_or_IS(), delta_s2, improv, sens, E);
+		   its->IT_ST_or_IS(), delta_s2, improv, sens, E);
   /* make sure the first col still indicates the coarse or fine process */
   if(params->BasePrior()->BaseModel() == GP){
     if( ((Gp_Prior*) params->BasePrior())->CorrPrior()->CorrModel() == MREXPSEP ){ 
@@ -274,7 +286,7 @@ void Tgp::Init(void)
   }
 
   /* print the parameters of this module */
-  if(verb >= 2) Print(mystdout);
+  if(verb >= 2) Print(MYstdout);
 }  
 
 
@@ -290,7 +302,7 @@ void Tgp::Rounds(void)
   for(unsigned int i=0; i<R; i++) {
 
     /* for periodically passing control back to R */
-    itime = my_r_process_events(itime);
+    itime = MY_r_process_events(itime);
     
     /* Linear Model Initialization rounds -B thru 1 */
     if(linburn) model->Linburn(B, state);
@@ -310,7 +322,7 @@ void Tgp::Rounds(void)
     model->Sample(preds, T-B, state);
 
     /* print tree statistics */
-    if(verb >= 1) model->PrintTreeStats(mystdout);
+    if(verb >= 1) model->PrintTreeStats(MYstdout);
 
     /* accumulate predictive information */
     import_preds(cump, preds->R * i, preds);		
@@ -320,7 +332,7 @@ void Tgp::Rounds(void)
 
     /* prune the tree all the way back unless importance tempering */
     if(R > 1) {
-      if(verb >= 1) myprintf(mystdout, "finished repetition %d of %d\n", i+1, R);
+      if(verb >= 1) MYprintf(MYstdout, "finished repetition %d of %d\n", i+1, R);
       if(its->Numit() == 1) model->cut_root();
     }
 
@@ -331,7 +343,7 @@ void Tgp::Rounds(void)
   }
 
   /* cap off the printing */
-  if(verb >= 1) myflush(mystdout);
+  if(verb >= 1) MYflush(MYstdout);
 
   /* print the rectangle of the MAP partition */
   model->PrintBestPartitions();   
@@ -380,12 +392,12 @@ void Tgp::Rounds(void)
 void Tgp::Predict(void)
 {
   /* don't need multiple rounds R when just kriging */
-  if(R > 1) warning("R=%d (>0) not necessary for Kriging", R);
+  if(R > 1) Rf_warning("R=%d (>0) not necessary for Kriging", R);
 
   for(unsigned int i=0; i<R; i++) {
 
     /* for periodically passing control back to R */
-    itime = my_r_process_events(itime);
+    itime = MY_r_process_events(itime);
 
     /* do the MCMC rounds B,...,T */
     preds = new_preds(XX, nn, pred_n*n, d, rect, T-B, pred_n, krige, 
@@ -398,13 +410,13 @@ void Tgp::Predict(void)
 
     /* done with this repetition; prune the tree all the way back */
     if(R > 1) {
-      myprintf(mystdout, "finished repetition %d of %d\n", i+1, R);
+      MYprintf(MYstdout, "finished repetition %d of %d\n", i+1, R);
       // model->cut_root();
     }
   }
 
   /* cap of the printing */
-  if(verb >= 1) myflush(mystdout);
+  if(verb >= 1) MYflush(MYstdout);
 
   /* these is here to maintain compatibility with tgp::Rounds() */
 
@@ -523,7 +535,7 @@ void Tgp::GetStats(bool report, double *Zp_mean, double *ZZ_mean, double *Zp_km,
 		   double *ZZ_median, double *ZZ_q2, double *Ds2x, double *improvec,
 		   int numirank, int* irank, double *ess)
 {
-  itime = my_r_process_events(itime);
+  itime = MY_r_process_events(itime);
 
   /* possibly adjust weights by the chosen lambda method,
      and possibly write the trace out to a file*/
@@ -581,7 +593,6 @@ void Tgp::GetStats(bool report, double *Zp_mean, double *ZZ_mean, double *Zp_km,
     /* mean */
     wmean_of_columns(ZZ_mean, cump->ZZ, cump->R, nn, w);
 
-
     /* kriging mean */
     if(ZZ_km) wmean_of_columns(ZZ_km, cump->ZZm, cump->R, nn, w);
     if(ZZ_km) wvar_of_columns(ZZ_kvm, cump->ZZvm, cump->R, nn, w);
@@ -628,14 +639,6 @@ void Tgp::GetStats(bool report, double *Zp_mean, double *ZZ_mean, double *Zp_km,
       assert(cump->improv);
       
       wmean_of_columns(improvec, cump->improv, cump->R, cump->nn, w);
-      /* TADDY's file output for improv trace   
-      matrix_to_file("improv.txt", cump->improv, cump->R, cump->nn);
-      int **IRANK = new int*[2];
-      IRANK[0] = (int*) GetImprovRank(cump->R, cump->nn, cump->improv, 1, w);
-      IRANK[1] = (int*) GetImprovRank(cump->R, cump->nn, cump->improv, 2, w);
-      dupiv(irank, IRANK[0], nn);
-      intmatrix_to_file("irank.txt", IRANK, 2, cump->nn);
-      delete_imatrix(IRANK); */
       int *ir = (int*) GetImprovRank(cump->R, cump->nn, cump->improv, improv, numirank, w);
       dupiv(irank, ir, nn);
       free(ir);
@@ -663,13 +666,13 @@ void tgp_cleanup(void)
     deleteRNGstate(tgp_state);
     tgp_state = NULL;
     if(tgpm->Verb() >= 1) 
-      myprintf(mystderr, "INTERRUPT: tgp RNG leaked, is now destroyed\n");
+      MYprintf(MYstderr, "INTERRUPT: tgp RNG leaked, is now destroyed\n");
   }
 
   /* free tgp model */
   if(tgpm) { 
     if(tgpm->Verb() >= 1)
-      myprintf(mystderr, "INTERRUPT: tgp model leaked, is now destroyed\n");
+      MYprintf(MYstderr, "INTERRUPT: tgp model leaked, is now destroyed\n");
     delete tgpm; 
     tgpm = NULL; 
   }
@@ -710,27 +713,27 @@ double ** getXdataRect(double **X, unsigned int n, unsigned int d, double **XX,
 
 void Tgp::Print(FILE *outfile)
 {
-  myprintf(mystdout, "\n");
+  MYprintf(MYstdout, "\n");
 
   /* DEBUG: print the input parameters */
-  myprintf(mystdout, "n=%d, d=%d, nn=%d\nBTE=(%d,%d,%d), R=%d, linburn=%d\n", 
+  MYprintf(MYstdout, "n=%d, d=%d, nn=%d\nBTE=(%d,%d,%d), R=%d, linburn=%d\n", 
 	   n, d, nn, B, T, E, R, linburn);
 
   /* print the importance tempring information */
-  its->Print(mystdout);
+  its->Print(MYstdout);
 
   /* print the random number generator state */
-  printRNGstate(state, mystdout);
+  printRNGstate(state, MYstdout);
 
   /* print predictive statistic types */
-  if(pred_n || (delta_s2 || improv)) myprintf(mystdout, "preds:");
-  if(pred_n) myprintf(mystdout, " data");
-  if(krige && (pred_n || nn)) myprintf(mystdout, " krige");
-  if(delta_s2) myprintf(mystdout, " ALC");
-  if(improv) myprintf(mystdout, " improv");
+  if(pred_n || (delta_s2 || improv)) MYprintf(MYstdout, "preds:");
+  if(pred_n) MYprintf(MYstdout, " data");
+  if(krige && (pred_n || nn)) MYprintf(MYstdout, " krige");
+  if(delta_s2) MYprintf(MYstdout, " ALC");
+  if(improv) MYprintf(MYstdout, " improv");
   if(pred_n || (((krige && (pred_n || nn)) || delta_s2) || improv)) 
-    myprintf(mystdout, "\n");
-  myflush(mystdout);
+    MYprintf(MYstdout, "\n");
+  MYflush(MYstdout);
 
   /* print the model, uses the internal model 
      printing variable OUTFILE */
